@@ -1,4 +1,4 @@
-// Copyright 2012-2014 Luis Pedro Coelho <luis@luispedro.org>
+// Copyright 2012-2019 Luis Pedro Coelho <luis@luispedro.org>
 // License: MIT (see COPYING.MIT file)
 
 #ifndef LPC_JPEG_H_INCLUDE_GUARD_THU_FEB__2_18_14_07_WET_2012
@@ -13,7 +13,7 @@ class JPEGFormat : public ImageFormat {
 
         static bool match_format(byte_source* src) { return match_magic(src, "\xff\xd8\xff", 3); }
 
-        std::auto_ptr<Image> read(byte_source* src, ImageFactory* factory, const options_map& opts);
+        std::unique_ptr<Image> read(byte_source* src, ImageFactory* factory, const options_map& opts);
         void write(Image* input, byte_sink* output, const options_map& opts);
 };
 
