@@ -1,4 +1,4 @@
-// Copyright 2012-2014 Luis Pedro Coelho <luis@luispedro.org>
+// Copyright 2012-2019 Luis Pedro Coelho <luis@luispedro.org>
 // License: MIT (see COPYING.MIT file)
 
 #include "base.h"
@@ -7,14 +7,14 @@
 
 #include <webp/decode.h>
 
-std::auto_ptr<Image> WebPFormat::read(byte_source* src, ImageFactory* factory, const options_map&) {
+std::unique_ptr<Image> WebPFormat::read(byte_source* src, ImageFactory* factory, const options_map&) {
     std::vector<byte> data = full_data(*src);
     int w, h;
     int ok = WebPGetInfo(&data[0], data.size(), &w, &h);
     if (!ok) {
         throw CannotReadError("imread.imread._webp: File does not validate as WebP");
     }
-    std::auto_ptr<Image> output(factory->create(8, h, w, 4));
+    std::unique_ptr<Image> output(factory->create(8, h, w, 4));
     const int stride = w*4;
     const uint8_t* p = WebPDecodeRGBAInto(
             &data[0], data.size(),
