@@ -1,4 +1,4 @@
-// Copyright 2012 Luis Pedro Coelho <luis@luispedro.org>
+// Copyright 2012-2020 Luis Pedro Coelho <luis@luispedro.org>
 // License: MIT (see COPYING.MIT file)
 #ifndef LPC_FILE_H_INCLUDE_GUARD_WED_FEB__1_16_34_50_WET_2012
 #define LPC_FILE_H_INCLUDE_GUARD_WED_FEB__1_16_34_50_WET_2012
@@ -23,9 +23,9 @@ class fd_source_sink : public byte_source, public byte_sink {
             return ::read(fd_, buffer, n);
         }
         virtual bool can_seek() const { return true; }
-        virtual size_t seek_absolute(size_t pos) { return ::lseek(fd_, pos, SEEK_SET); }
-        virtual size_t seek_relative(int delta) { return ::lseek(fd_, delta, SEEK_CUR); }
-        virtual size_t seek_end(int delta) { return ::lseek(fd_, delta, SEEK_END); }
+        virtual size_t seek_absolute(size_t pos) { return _check_seek(fd_, pos, SEEK_SET); }
+        virtual size_t seek_relative(int delta) { return _check_seek(fd_, delta, SEEK_CUR); }
+        virtual size_t seek_end(int delta) { return _check_seek(fd_, delta, SEEK_END); }
 
 
         virtual size_t write(const byte* buffer, size_t n) {
@@ -33,6 +33,13 @@ class fd_source_sink : public byte_source, public byte_sink {
         }
     private:
         int fd_;
+        static off_t _check_seek(int fd, off_t offset, int whence) {
+            off_t r = ::lseek(fd, offset, whence);
+            if (r == static_cast<off_t>(-1)) {
+                throw CannotSeekError();
+            }
+            return r;
+        }
 };
 
 #endif // LPC_FILE_H_INCLUDE_GUARD_WED_FEB__1_16_34_50_WET_2012
