@@ -1,4 +1,4 @@
-// Copyright 2012-2014 Luis Pedro Coelho <luis@luispedro.org>
+// Copyright 2012-2019 Luis Pedro Coelho <luis@luispedro.org>
 // License: MIT (see COPYING.MIT file)
 
 #ifndef LPC_FORMATS_H_INCLUDE_GUARD_WED_FEB__1_16_34_50_WET_2012
@@ -6,7 +6,7 @@
 #include "base.h"
 #include <memory>
 
-std::auto_ptr<ImageFormat> get_format(const char*);
+std::unique_ptr<ImageFormat> get_format(const char*);
 const char* magic_format(byte_source*);
 
 #endif // LPC_FORMATS_H_INCLUDE_GUARD_WED_FEB__1_16_34_50_WET_2012
